package com.bweb.controller;

import com.hai.common.exception.ErrorCode;
import com.hai.common.exception.ErrorHelp;
import com.hai.common.exception.SysCode;
import com.hai.common.security.SessionObject;
import com.hai.common.security.UserCenter;
import com.hai.common.utils.ResponseMsgUtil;
import com.hai.entity.HighAgent;
import com.hai.entity.HighCoupon;
import com.hai.entity.HighCouponAgentRel;
import com.hai.model.HighAgentModel;
import com.hai.model.ResponseData;
import com.hai.model.UserInfoModel;
import com.hai.service.HighAgentService;
import com.hai.service.HighCouponAgentService;
import com.hai.service.HighCouponService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.util.Date;

/**
 * @Auther: 胡锐
 * @Description:
 * @Date: 2021/4/20 23:47
 */
@Controller
@RequestMapping(value = "/highCouponAgent")
@Api(value = "代理商接口")
public class HighCouponAgentController {

    private static Logger log = LoggerFactory.getLogger(HighCouponAgentController.class);

    @Resource
    private HighCouponAgentService highCouponAgentService;

    @Resource
    private HighAgentService highAgentService;

    @Autowired
    private UserCenter userCenter;

    @Resource
    private HighCouponService highCouponService;

    @RequestMapping(value = "/assignCouponAgent", method = RequestMethod.POST)
    @ResponseBody
    @ApiOperation(value = "分配卡券给代理商")
    public ResponseData assignCouponAgent(@RequestBody HighCouponAgentRel highCouponAgentRel, HttpServletRequest request) {
        try {
            //发布人员
            SessionObject sessionObject = userCenter.getSessionObject(request);
            UserInfoModel userInfoModel = (UserInfoModel) sessionObject.getObject();
            if (userInfoModel.getBsCompany() == null) {
                log.error("HighAgentController -> insertAgent() error!","该主角色没有权限");
                throw ErrorHelp.genException(SysCode.System, ErrorCode.MENU_TREE_HAS_NOT_ERROR, "");
            }

            if(highCouponAgentRel.getCouponId() == null
                || highCouponAgentRel.getAgentId() == null
                || highCouponAgentRel.getStockCount() == null) {
                log.error("HighAgentController -> insertAgent() error!","参数错误");
                throw ErrorHelp.genException(SysCode.System, ErrorCode.REQ_PARAMS_ERROR, "");
            }

            // 查询卡券详情
            HighCoupon coupon = highCouponService.getCouponById(highCouponAgentRel.getCouponId());
            if (coupon == null) {
                log.error("HighAgentController -> insertAgent() error!","未找到卡券信息");
                throw ErrorHelp.genException(SysCode.System, ErrorCode.NOT_FOUND_COUPON, "");
            }

            // 查询代理商
            HighAgent highAgent = highAgentService.findByAgentMsgId(highCouponAgentRel.getAgentId());
            if (highAgent == null) {
                log.error("HighAgentController -> insertAgent() error!","未找到代理商信息");
                throw ErrorHelp.genException(SysCode.System, ErrorCode.NOT_FOUND_AGENT, "");
            }

            // 校验是否重复分配
            if (highCouponAgentService.getRelByCouponAgent(highCouponAgentRel.getCouponId(),highCouponAgentRel.getAgentId()) != null) {
                log.error("HighAgentController -> insertAgent() error!","参数错误");
                throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, coupon.getCouponName() + "已分配给" + highAgent.getAgentName());
            }

            highCouponAgentRel.setCouponName(coupon.getCouponName());
            highCouponAgentRel.setSalesPrice(coupon.getSalesPrice());
            highCouponAgentRel.setStatus(1); // 状态 0：删除  1：正常
            highCouponAgentRel.setCreateTime(new Date());
            highCouponAgentRel.setOperatorId(userInfoModel.getSecUser().getId());
            highCouponAgentRel.setOperatorName(userInfoModel.getSecUser().getUserName());
            highCouponAgentService.assignCouponAgent(highCouponAgentRel);

            return ResponseMsgUtil.success("分配成功");

        } catch (Exception e) {
            log.error("HighAgentController --> assignCouponAgent() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }


}
